function v=compute_inflow_surge_bt(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes inflow surge t shift
% Script automatically generated by fit_inflow_surge_bt.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.86408
% RMSE  = 1.0491
% MEAN  = 2.9283
% RANGE = -1.8468 - 9.9734

beta( 1 )= -6.4710e+00 ;
beta( 2 )= 8.1407e+01 ;
beta( 3 )= 8.3692e-01 ;
beta( 4 )= 3.0154e-01 ;
beta( 5 )= 5.2889e-01 ;

v=beta(1)+beta(2).*(cos(phi*pi/180).*vt).^-1 + beta(3).*a.^beta(4).*w.^beta(5);
